{ config, lib, pkgs, custompkgs, modulesPath, allPkgs, ... }:

{
  imports =
    [];

  # packages to exclude from default gnome
  environment.gnome.excludePackages = (with pkgs; [
    gnome-photos
    gnome-tour
  ]) ++ (with pkgs.gnome; [
    gnome-music
    yelp # help viewer
    epiphany # web browser
    geary # email reader
    totem # video player
    tali # poker game
    iagno # go game
    hitori # sudoku game
    atomix # puzzle game
  ]);

  # disable xterm
  services.xserver.excludePackages = [ pkgs.xterm ]; 

  # disable documentation install
  documentation.nixos.enable = false;

  # cli util to upate hardware
  services.fwupd.enable = true;
  programs.steam.enable = true;
  virtualisation.docker.enable = true;

  # use zsh shell
  programs.zsh.enable = true;

  # enable virtualization support for eg. boxes
  virtualisation.libvirtd.enable = true;

  # packages in global env
  environment.systemPackages = with pkgs; [
    # system utilities
    wget
    scrcpy
    cmake
    lm_sensors
    smartmontools
    powertop
    htop
    radeontop
    neofetch
    dmidecode

    (pkgs.callPackage ./resources.nix { })
    bottles

    # web
    firefox
    # development
    openscad
    vscode
    git
    ninja
    flutter
    prusa-slicer

    iperf3
    discord
    
    rustup
    gcc
    sqlite
    sea-orm-cli
    poetry
    python3
    
    ## ides
    jetbrains.idea-ultimate
    jetbrains.dataspell
    jetbrains.rust-rover
    gnome-builder
    gnome.gnome-boxes

    ## R statistics stuff
    rstudio
    R

    # multimedia
    vlc
    gimp
    zoom-us

    # file transfer
    warp

    # gui utilities
    pdfarranger
    diebahn
    appflowy
    kicad
    authenticator
    dialect
    gnome-decoder
    video-trimmer
    pods

    eyedropper
    gaphor
  ] ++ ([
    #custompkgs.resources
    ]);
}